==> zio-aws-wafregional_3-5.17.102.8-sources.jar: zio/aws/wafregional/model/ListTagsForResourceResponse.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.NextMarker
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListTagsForResourceResponse(
    nextMarker: Option[NextMarker] = None,
    tagInfoForResource: Option[zio.aws.wafregional.model.TagInfoForResource] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse = {
    import ListTagsForResourceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(tagInfoForResource.map(value => value.buildAwsValue()))(
        _.tagInfoForResource
      )
      .build()
  }
  def asReadOnly
      : zio.aws.wafregional.model.ListTagsForResourceResponse.ReadOnly =
    zio.aws.wafregional.model.ListTagsForResourceResponse.wrap(buildAwsValue())
}
object ListTagsForResourceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.ListTagsForResourceResponse =
      zio.aws.wafregional.model.ListTagsForResourceResponse(
        nextMarker.map(value => value),
        tagInfoForResource.map(value => value.asEditable)
      )
    def nextMarker: Option[NextMarker]
    def tagInfoForResource
        : Option[zio.aws.wafregional.model.TagInfoForResource.ReadOnly]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getTagInfoForResource: ZIO[
      Any,
      AwsError,
      zio.aws.wafregional.model.TagInfoForResource.ReadOnly
    ] = AwsError.unwrapOptionField("tagInfoForResource", tagInfoForResource)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ) extends zio.aws.wafregional.model.ListTagsForResourceResponse.ReadOnly {
    override val nextMarker: Option[NextMarker] = scala
      .Option(impl.nextMarker())
      .map(value => zio.aws.wafregional.model.primitives.NextMarker(value))
    override val tagInfoForResource
        : Option[zio.aws.wafregional.model.TagInfoForResource.ReadOnly] = scala
      .Option(impl.tagInfoForResource())
      .map(value => zio.aws.wafregional.model.TagInfoForResource.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ): zio.aws.wafregional.model.ListTagsForResourceResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-wafregional_3-5.17.295.10-sources.jar: zio/aws/wafregional/model/ListTagsForResourceResponse.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.NextMarker
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListTagsForResourceResponse(
    nextMarker: Optional[NextMarker] = Optional.Absent,
    tagInfoForResource: Optional[zio.aws.wafregional.model.TagInfoForResource] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse = {
    import ListTagsForResourceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(tagInfoForResource.map(value => value.buildAwsValue()))(
        _.tagInfoForResource
      )
      .build()
  }
  def asReadOnly
      : zio.aws.wafregional.model.ListTagsForResourceResponse.ReadOnly =
    zio.aws.wafregional.model.ListTagsForResourceResponse.wrap(buildAwsValue())
}
object ListTagsForResourceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.ListTagsForResourceResponse =
      zio.aws.wafregional.model.ListTagsForResourceResponse(
        nextMarker.map(value => value),
        tagInfoForResource.map(value => value.asEditable)
      )
    def nextMarker: Optional[NextMarker]
    def tagInfoForResource
        : Optional[zio.aws.wafregional.model.TagInfoForResource.ReadOnly]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getTagInfoForResource: ZIO[
      Any,
      AwsError,
      zio.aws.wafregional.model.TagInfoForResource.ReadOnly
    ] = AwsError.unwrapOptionField("tagInfoForResource", tagInfoForResource)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ) extends zio.aws.wafregional.model.ListTagsForResourceResponse.ReadOnly {
    override val nextMarker: Optional[NextMarker] = zio.aws.core.internal
      .optionalFromNullable(impl.nextMarker())
      .map(value => zio.aws.wafregional.model.primitives.NextMarker(value))
    override val tagInfoForResource
        : Optional[zio.aws.wafregional.model.TagInfoForResource.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tagInfoForResource())
        .map(value => zio.aws.wafregional.model.TagInfoForResource.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ): zio.aws.wafregional.model.ListTagsForResourceResponse.ReadOnly =
    new Wrapper(impl)
}
